@@ -18,7 +18,7 @@ import (
 	"time"
 
 	"github.com/ProtonMail/gopenpgp/v2/crypto" // MIT License
-	"github.com/mattn/go-xmpp"                // BSD-3-Clause
+	"github.com/mattn/go-xmpp"                 // BSD-3-Clause
 	"github.com/pborman/getopt/v2"             // BSD-3-Clause
 )
 
@@ -122,6 +122,7 @@ func main() {
 	flagOxDeleteNodes := getopt.BoolLong("ox-delete-nodes", 0, "Delete existing OpenPGP nodes on the server.")
 	flagOOBFile := getopt.StringLong("oob-file", 0, "", "URL to send a file as out of band data.")
 	flagHeadline := getopt.BoolLong("headline", 0, "Send message as type headline.")
+	flagSCRAMPinning := getopt.StringLong("scram-mech-pinning", 0, "", "Enforce the use of a certain SCRAM authentication mechanism.")
 
 	// Parse command line flags.
 	getopt.Parse()
@@ -156,6 +157,13 @@ func main() {
 		log.Fatal("Can't use message type headline for groupchat messages.")
 	}
 
+	switch *flagSCRAMPinning {
+	case "", "SCRAM-SHA-1", "SCRAM-SHA-1-PLUS", "SCRAM-SHA-256", "SCRAM-SHA-256-PLUS",
+		"SCRAM-SHA-512", "SCRAM-SHA-512-PLUS":
+	default:
+		log.Fatal("Unknown SCRAM mechanism: ", *flagSCRAMPinning)
+	}
+
 	// Read recipients from command line and quit if none are specified.
 	// For listening or sending raw XML it's not required to specify a recipient except
 	// when sending raw messages to MUCs (go-sendxmpp will join the MUC automatically).
@@ -229,9 +237,6 @@ func main() {
 		os.Exit(0)
 	}
 
-	// Check whether an authentification mechanism is pinned.
-	authMech, _ := parsePinFile(user)
-
 	// Set XMPP connection options.
 	options := xmpp.Options{
 		Host:        server,
@@ -249,7 +254,7 @@ func main() {
 		StartTLS:  !*flagDirectTLS,
 		Debug:     *flagDebug,
 		TLSConfig: &tlsConfig,
-		Mechanism: authMech,
+		Mechanism: *flagSCRAMPinning,
 	}
 
 	// Read message from file.
@@ -296,14 +301,6 @@ func main() {
 	if err != nil {
 		log.Fatal(err)
 	}
-	// If no authentification mechanism is pinned and a SCRAM mechanism is
-	// used, write the used mechanism to the pin file.
-	if authMech == "" && strings.HasPrefix(client.Mechanism, "SCRAM") {
-		err = writePinFile(client.Mechanism, user)
-		if err != nil {
-			log.Println("could not write authentification mechanism pin file:", err)
-		}
-	}
 
 	iqc := make(chan xmpp.IQ, defaultBufferSize)
 	msgc := make(chan xmpp.Chat, defaultBufferSize)
